Module position

Module position 

Structs

Position
A cursor location. col is a grapheme index, never a byte or char offset.

Functions

display_to_grapheme_col
Grapheme index containing display_col.
display_width
Total display columns, using the default tab width of 4.
display_width_with_tabs
Total display columns a string occupies, expanding tabs to tab_width stops.
grapheme_to_display_col
Display column at which the grapheme at grapheme_idx begins.