Structs
- Position
- A cursor location.
colis a grapheme index, never a byte or char offset.
Functions
- display_
to_ grapheme_ col - Grapheme index containing
display_col. - display_
width - Total display columns, using the default tab width of 4.
- display_
width_ with_ tabs - Total display columns a string occupies, expanding tabs to
tab_widthstops. - grapheme_
to_ display_ col - Display column at which the grapheme at
grapheme_idxbegins.